local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
	vim.fn.system({
		"git",
		"clone",
		"--filter=blob:none",
		"https://github.com/folke/lazy.nvim.git",
		"--branch=stable", -- latest stable release
		lazypath,
	})
end
vim.opt.rtp:prepend(lazypath)

-- Example using a list of specs with the default options
vim.g.mapleader = " " -- Make sure to set `mapleader` before lazy so your mappings are correct

require("lazy").setup({
	{
		"mhartington/oceanic-next",
		config = function()
			vim.cmd("syntax enable")
			vim.cmd("colorscheme OceanicNext")
		end,
	},
	{
		"ggandor/leap.nvim",
		lazy = false,
		config = function()
            require("core.utils").load_mappings "leap"
		end,
	},
	{
		"ggandor/flit.nvim",
		lazy = false,
		config = function()
			require("flit").setup({
				keys = { f = "f", F = "F", t = "t", T = "T" },
				-- A string like "nv", "nvo", "o", etc.
				labeled_modes = "v",
				multiline = true,
				-- Like `leap`s similar argument (call-specific overrides).
				-- E.g.: opts = { equivalence_classes = {} }
				opts = {},
			})
		end,
	},
	{
		"echasnovski/mini.trailspace",
		lazy = false,
		event = { "BufReadPost", "BufNewFile" },
		opts = {},
		config = function()
            require("core.utils").load_mappings "trailspace"
		end,
	},
	{
		-- exit insert mode with 'jk'
		"max397574/better-escape.nvim",
		enabled = true,
		event = "InsertEnter",
		config = function()
			require("better_escape").setup()
		end,
	},
	{
		"dhruvasagar/vim-table-mode",
		lazy = false,
		-- <Leader>tm is automatically set for toggle
		-- see <Leader>t menu
	},
	"nvim-tree/nvim-web-devicons",
	{
		"nvim-tree/nvim-tree.lua",
		lazy = false,
		config = function()
			require("nvim-tree").setup()
		end,
	},
})
